import useSettingsStore from '@/settings/useSettingsStore'
import useTimeStore from '@/utils/useTimeStore'
import { Lunar } from 'lunar-typescript'
import { computed, defineComponent, Transition } from 'vue'
import useLayoutStore from '../useLayoutStore'

export default defineComponent({
  setup() {
    const time = useTimeStore()
    const text = computed(() => {
      const h = time.date.getHours()
      const hour = h < 10 ? '0' + h : h
      const m = time.date.getMinutes()
      const minute = m < 10 ? '0' + m : m
      const s = time.date.getSeconds()
      const second = s < 10 ? '0' + s : s
      const dateStr = `${time.date.getMonth() + 1}月${time.date.getDate()}日`
      return {
        timeStr: `${hour}:${minute}:${second}`,
        dateStr
      }
    })
    const info = computed(() => {
      const l = Lunar.fromDate(time.date)
      const day = l.getMonthInChinese() + '月' + l.getDayInChinese()
      const dayWeek = l.getWeekInChinese()
      return {
        day,
        dayWeek
      }
    })
    const settings = useSettingsStore()
    const layout = useLayoutStore()
    return () => (
      <div
        class="absolute z-20 shadow-text tracking-widest font-mono font-bold h-[110px] transition-all"
        style={{
          color: layout.isCompact ? 'white' : 'rgba(255,255,255,.8)',
          transitionDuration: '.4s',
          left: layout.isCompact ? '20px' : '50%',
          top: layout.isCompact ? '20px' : '50px',
          transform: layout.isCompact ? '' : 'translate(-50%,0)'
        }}
      >
        <Transition>
          {settings.state.showDate && (
            <div
              class={
                'transition-all ' +
                (layout.isCompact ? 'text-[1.4rem] leading-[1.4rem]' : 'text-[4rem] leading-[4rem]')
              }
            >
              {text.value.timeStr}
            </div>
          )}
        </Transition>
        <Transition>
          {settings.state.showTime && (
            <div
              class={'flex items-center gap-4 mt-4 ' + (layout.isCompact ? '' : 'justify-center')}
            >
              <div>{text.value.dateStr}</div>
              <Transition>{!layout.isCompact && <div>星期{info.value.dayWeek}</div>}</Transition>
              <Transition>{!layout.isCompact && <div>{info.value.day}</div>}</Transition>
            </div>
          )}
        </Transition>
      </div>
    )
  }
})
