import { defineComponent, reactive, Transition } from 'vue'
import useRouterStore from '@/useRouterStore'
import request from '@/utils/request'
import useUserStore from './useUserStore'

export default defineComponent(() => {
  const router = useRouterStore()
  const user = useUserStore()
  const form = reactive({
    email: '',
    password: ''
  })
  return () => (
    <div class="fixed left-0 top-0 z-50 w-full">
      <Transition>
        {router.path === 'global-login' && (
          <div
            class="w-full h-screen bg-black/20 backdrop-blur"
            onClick={() => {
              router.path = ''
            }}
          ></div>
        )}
      </Transition>
      <Transition name="modal">
        {router.path === 'global-login' && (
          <div class="absolute left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 overflow-hidden transition-all w-[540px] max-w-[90%] rounded-lg p-2 bg-white/40 backdrop-blur">
            <div class="w-full h-full rounded-lg bg-white/80 overflow-hidden">
              <div class="flex justify-center py-4">
                <img src="/logo.png" alt="logo" class="w-1/3" />
              </div>
              <div class="text-center text-lg text-black/60 font-bold tracking-widest">
                登录 Fatfox 新标签页
              </div>
              <div class="flex flex-col">
                测试用
                <form>
                  <input placeholder="邮箱" v-model={form.email} />
                  <input placeholder="密码" type="password" v-model={form.password} />
                </form>
                <button
                  onClick={() => {
                    request<string>('POST', '/api/user/login', {
                      data: form,
                      returnType: 'text'
                    }).then((res) => {
                      user.token = res
                      router.path = ''
                    })
                  }}
                >
                  立即登录
                </button>
              </div>
              <div class="flex justify-end py-4">
                <img src="/logo.png" alt="logo" class="w-1/2 relative top-8 left-4 opacity-10" />
              </div>
            </div>
          </div>
        )}
      </Transition>
    </div>
  )
})
